userpb

package
v0.0.0-...-967a65d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 29, 2022 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_userpb_user_proto protoreflect.FileDescriptor
var UserService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "userpb.UserService",
	HandlerType: (*UserServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "CreateUser",
			Handler:    _UserService_CreateUser_Handler,
		},
		{
			MethodName: "DeleteUser",
			Handler:    _UserService_DeleteUser_Handler,
		},
		{
			MethodName: "IssueToken",
			Handler:    _UserService_IssueToken_Handler,
		},
		{
			MethodName: "AuthUser",
			Handler:    _UserService_AuthUser_Handler,
		},
	},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "GetAllUser",
			Handler:       _UserService_GetAllUser_Handler,
			ServerStreams: true,
		},
	},
	Metadata: "userpb/user.proto",
}

UserService_ServiceDesc is the grpc.ServiceDesc for UserService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterUserServiceServer

func RegisterUserServiceServer(s grpc.ServiceRegistrar, srv UserServiceServer)

Types

type AuthUserRequest

type AuthUserRequest struct {
	Token *Token `protobuf:"bytes,1,opt,name=token,proto3" json:"token,omitempty"`
	// contains filtered or unexported fields
}

func (*AuthUserRequest) Descriptor deprecated

func (*AuthUserRequest) Descriptor() ([]byte, []int)

Deprecated: Use AuthUserRequest.ProtoReflect.Descriptor instead.

func (*AuthUserRequest) GetToken

func (x *AuthUserRequest) GetToken() *Token

func (*AuthUserRequest) ProtoMessage

func (*AuthUserRequest) ProtoMessage()

func (*AuthUserRequest) ProtoReflect

func (x *AuthUserRequest) ProtoReflect() protoreflect.Message

func (*AuthUserRequest) Reset

func (x *AuthUserRequest) Reset()

func (*AuthUserRequest) String

func (x *AuthUserRequest) String() string

type AuthUserResponse

type AuthUserResponse struct {
	// contains filtered or unexported fields
}

func (*AuthUserResponse) Descriptor deprecated

func (*AuthUserResponse) Descriptor() ([]byte, []int)

Deprecated: Use AuthUserResponse.ProtoReflect.Descriptor instead.

func (*AuthUserResponse) ProtoMessage

func (*AuthUserResponse) ProtoMessage()

func (*AuthUserResponse) ProtoReflect

func (x *AuthUserResponse) ProtoReflect() protoreflect.Message

func (*AuthUserResponse) Reset

func (x *AuthUserResponse) Reset()

func (*AuthUserResponse) String

func (x *AuthUserResponse) String() string

type CreateUserRequest

type CreateUserRequest struct {
	User *User `protobuf:"bytes,1,opt,name=user,proto3" json:"user,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateUserRequest) Descriptor deprecated

func (*CreateUserRequest) Descriptor() ([]byte, []int)

Deprecated: Use CreateUserRequest.ProtoReflect.Descriptor instead.

func (*CreateUserRequest) GetUser

func (x *CreateUserRequest) GetUser() *User

func (*CreateUserRequest) ProtoMessage

func (*CreateUserRequest) ProtoMessage()

func (*CreateUserRequest) ProtoReflect

func (x *CreateUserRequest) ProtoReflect() protoreflect.Message

func (*CreateUserRequest) Reset

func (x *CreateUserRequest) Reset()

func (*CreateUserRequest) String

func (x *CreateUserRequest) String() string

type CreateUserResponse

type CreateUserResponse struct {
	Id int32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateUserResponse) Descriptor deprecated

func (*CreateUserResponse) Descriptor() ([]byte, []int)

Deprecated: Use CreateUserResponse.ProtoReflect.Descriptor instead.

func (*CreateUserResponse) GetId

func (x *CreateUserResponse) GetId() int32

func (*CreateUserResponse) ProtoMessage

func (*CreateUserResponse) ProtoMessage()

func (*CreateUserResponse) ProtoReflect

func (x *CreateUserResponse) ProtoReflect() protoreflect.Message

func (*CreateUserResponse) Reset

func (x *CreateUserResponse) Reset()

func (*CreateUserResponse) String

func (x *CreateUserResponse) String() string

type DeleteUserRequest

type DeleteUserRequest struct {
	Id int32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

func (*DeleteUserRequest) Descriptor deprecated

func (*DeleteUserRequest) Descriptor() ([]byte, []int)

Deprecated: Use DeleteUserRequest.ProtoReflect.Descriptor instead.

func (*DeleteUserRequest) GetId

func (x *DeleteUserRequest) GetId() int32

func (*DeleteUserRequest) ProtoMessage

func (*DeleteUserRequest) ProtoMessage()

func (*DeleteUserRequest) ProtoReflect

func (x *DeleteUserRequest) ProtoReflect() protoreflect.Message

func (*DeleteUserRequest) Reset

func (x *DeleteUserRequest) Reset()

func (*DeleteUserRequest) String

func (x *DeleteUserRequest) String() string

type DeleteUserResponse

type DeleteUserResponse struct {
	// contains filtered or unexported fields
}

func (*DeleteUserResponse) Descriptor deprecated

func (*DeleteUserResponse) Descriptor() ([]byte, []int)

Deprecated: Use DeleteUserResponse.ProtoReflect.Descriptor instead.

func (*DeleteUserResponse) ProtoMessage

func (*DeleteUserResponse) ProtoMessage()

func (*DeleteUserResponse) ProtoReflect

func (x *DeleteUserResponse) ProtoReflect() protoreflect.Message

func (*DeleteUserResponse) Reset

func (x *DeleteUserResponse) Reset()

func (*DeleteUserResponse) String

func (x *DeleteUserResponse) String() string

type GetAllUserRequest

type GetAllUserRequest struct {
	// contains filtered or unexported fields
}

func (*GetAllUserRequest) Descriptor deprecated

func (*GetAllUserRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetAllUserRequest.ProtoReflect.Descriptor instead.

func (*GetAllUserRequest) ProtoMessage

func (*GetAllUserRequest) ProtoMessage()

func (*GetAllUserRequest) ProtoReflect

func (x *GetAllUserRequest) ProtoReflect() protoreflect.Message

func (*GetAllUserRequest) Reset

func (x *GetAllUserRequest) Reset()

func (*GetAllUserRequest) String

func (x *GetAllUserRequest) String() string

type GetAllUserResponse

type GetAllUserResponse struct {
	User *User `protobuf:"bytes,1,opt,name=user,proto3" json:"user,omitempty"`
	// contains filtered or unexported fields
}

func (*GetAllUserResponse) Descriptor deprecated

func (*GetAllUserResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetAllUserResponse.ProtoReflect.Descriptor instead.

func (*GetAllUserResponse) GetUser

func (x *GetAllUserResponse) GetUser() *User

func (*GetAllUserResponse) ProtoMessage

func (*GetAllUserResponse) ProtoMessage()

func (*GetAllUserResponse) ProtoReflect

func (x *GetAllUserResponse) ProtoReflect() protoreflect.Message

func (*GetAllUserResponse) Reset

func (x *GetAllUserResponse) Reset()

func (*GetAllUserResponse) String

func (x *GetAllUserResponse) String() string

type IssueTokenRequest

type IssueTokenRequest struct {
	User *User `protobuf:"bytes,1,opt,name=user,proto3" json:"user,omitempty"`
	// contains filtered or unexported fields
}

func (*IssueTokenRequest) Descriptor deprecated

func (*IssueTokenRequest) Descriptor() ([]byte, []int)

Deprecated: Use IssueTokenRequest.ProtoReflect.Descriptor instead.

func (*IssueTokenRequest) GetUser

func (x *IssueTokenRequest) GetUser() *User

func (*IssueTokenRequest) ProtoMessage

func (*IssueTokenRequest) ProtoMessage()

func (*IssueTokenRequest) ProtoReflect

func (x *IssueTokenRequest) ProtoReflect() protoreflect.Message

func (*IssueTokenRequest) Reset

func (x *IssueTokenRequest) Reset()

func (*IssueTokenRequest) String

func (x *IssueTokenRequest) String() string

type IssueTokenResponse

type IssueTokenResponse struct {
	Token *Token `protobuf:"bytes,1,opt,name=token,proto3" json:"token,omitempty"`
	// contains filtered or unexported fields
}

func (*IssueTokenResponse) Descriptor deprecated

func (*IssueTokenResponse) Descriptor() ([]byte, []int)

Deprecated: Use IssueTokenResponse.ProtoReflect.Descriptor instead.

func (*IssueTokenResponse) GetToken

func (x *IssueTokenResponse) GetToken() *Token

func (*IssueTokenResponse) ProtoMessage

func (*IssueTokenResponse) ProtoMessage()

func (*IssueTokenResponse) ProtoReflect

func (x *IssueTokenResponse) ProtoReflect() protoreflect.Message

func (*IssueTokenResponse) Reset

func (x *IssueTokenResponse) Reset()

func (*IssueTokenResponse) String

func (x *IssueTokenResponse) String() string

type Token

type Token struct {
	Token string `protobuf:"bytes,1,opt,name=token,proto3" json:"token,omitempty"`
	Valid bool   `protobuf:"varint,2,opt,name=valid,proto3" json:"valid,omitempty"`
	// contains filtered or unexported fields
}

func (*Token) Descriptor deprecated

func (*Token) Descriptor() ([]byte, []int)

Deprecated: Use Token.ProtoReflect.Descriptor instead.

func (*Token) GetToken

func (x *Token) GetToken() string

func (*Token) GetValid

func (x *Token) GetValid() bool

func (*Token) ProtoMessage

func (*Token) ProtoMessage()

func (*Token) ProtoReflect

func (x *Token) ProtoReflect() protoreflect.Message

func (*Token) Reset

func (x *Token) Reset()

func (*Token) String

func (x *Token) String() string

type UnimplementedUserServiceServer

type UnimplementedUserServiceServer struct {
}

UnimplementedUserServiceServer must be embedded to have forward compatible implementations.

func (UnimplementedUserServiceServer) AuthUser

func (UnimplementedUserServiceServer) CreateUser

func (UnimplementedUserServiceServer) DeleteUser

func (UnimplementedUserServiceServer) GetAllUser

func (UnimplementedUserServiceServer) IssueToken

type UnsafeUserServiceServer

type UnsafeUserServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeUserServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to UserServiceServer will result in compilation errors.

type User

type User struct {
	Id       int32  `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	Email    string `protobuf:"bytes,2,opt,name=email,proto3" json:"email,omitempty"`
	Password string `protobuf:"bytes,3,opt,name=password,proto3" json:"password,omitempty"`
	// contains filtered or unexported fields
}

func (*User) Descriptor deprecated

func (*User) Descriptor() ([]byte, []int)

Deprecated: Use User.ProtoReflect.Descriptor instead.

func (*User) GetEmail

func (x *User) GetEmail() string

func (*User) GetId

func (x *User) GetId() int32

func (*User) GetPassword

func (x *User) GetPassword() string

func (*User) ProtoMessage

func (*User) ProtoMessage()

func (*User) ProtoReflect

func (x *User) ProtoReflect() protoreflect.Message

func (*User) Reset

func (x *User) Reset()

func (*User) String

func (x *User) String() string

type UserServiceClient

type UserServiceClient interface {
	CreateUser(ctx context.Context, in *CreateUserRequest, opts ...grpc.CallOption) (*CreateUserResponse, error)
	GetAllUser(ctx context.Context, in *GetAllUserRequest, opts ...grpc.CallOption) (UserService_GetAllUserClient, error)
	DeleteUser(ctx context.Context, in *DeleteUserRequest, opts ...grpc.CallOption) (*DeleteUserResponse, error)
	IssueToken(ctx context.Context, in *IssueTokenRequest, opts ...grpc.CallOption) (*IssueTokenResponse, error)
	AuthUser(ctx context.Context, in *AuthUserRequest, opts ...grpc.CallOption) (*AuthUserResponse, error)
}

UserServiceClient is the client API for UserService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type UserServiceServer

type UserServiceServer interface {
	CreateUser(context.Context, *CreateUserRequest) (*CreateUserResponse, error)
	GetAllUser(*GetAllUserRequest, UserService_GetAllUserServer) error
	DeleteUser(context.Context, *DeleteUserRequest) (*DeleteUserResponse, error)
	IssueToken(context.Context, *IssueTokenRequest) (*IssueTokenResponse, error)
	AuthUser(context.Context, *AuthUserRequest) (*AuthUserResponse, error)
	// contains filtered or unexported methods
}

UserServiceServer is the server API for UserService service. All implementations must embed UnimplementedUserServiceServer for forward compatibility

type UserService_GetAllUserClient

type UserService_GetAllUserClient interface {
	Recv() (*GetAllUserResponse, error)
	grpc.ClientStream
}

type UserService_GetAllUserServer

type UserService_GetAllUserServer interface {
	Send(*GetAllUserResponse) error
	grpc.ServerStream
}

Jump to